StringEllipsSizeExtension extension

Extension on String to truncate the string with an ellipsis.

on

Methods

ellipsSize({required int maxLength, bool fromStart = false}) String

Available on String, provided by the StringEllipsSizeExtension extension

ellipsSize Returns a new string truncated to the specified maximum length.