TreeOutPutItem<T> class

Constructors

TreeOutPutItem({required TreeInputItem<T> item, required int depth, required List<TreeOutPutItem<T>> children})

Properties

children List<TreeOutPutItem<T>>
final
depth int
final
hashCode int
The hash code for this object.
no setterinherited
item TreeInputItem<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited