GroupedRadioButtonItem<T> class

Constructors

GroupedRadioButtonItem({required Widget title, required T value, Widget? secondary})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Widget?
final
title Widget
final
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited